@@ -155,10 +155,13 @@ contrast = function(object, ...)
 #'
 #' @examples
 #' warp.lm <- lm(breaks ~ wool*tension, data = warpbreaks)
-#' warp.emm <- emmeans(warp.lm, ~ tension | wool)
+#' (warp.emm <- emmeans(warp.lm, ~ tension | wool))
 #' 
 #' contrast(warp.emm, "poly")    # inherits 'by = "wool"' from warp.emm
 #' 
+#' ### Custom contrast coefs (we already have wool as 'by' thus 3 means to contrast)
+#' contrast(warp.emm, list(mid.vs.ends = c(-1,2,-1)/2, lo.vs.hi = c(1,0,-1)))
+#' 
 #' pairs(warp.emm)
 #' 
 #' # Effects (dev from mean) of the 6 factor combs, with enhanced levels:
@@ -460,8 +463,7 @@ contrast.emmGrid = function(object, method = "eff", interaction = FALSE,
     # zap the transformation info except in special cases
     if (!is.null(misc$tran)) {
         misc$orig.tran = .fmt.tran(misc)
-        if (ratios && true.con && misc$tran %in% c("log", "log2", "log10", ### REMOVED "genlog", 
-                                                   "logit", "log.o.r.")) {
+        if (ratios && true.con && misc$orig.tran %in% c("log", "log2", "log10", "logit", "log.o.r.")) {
             misc$log.contrast = TRUE      # remember how we got here; used by summary
             misc$orig.inv.lbl = misc$inv.lbl
             if (misc$tran == "logit") {
@@ -563,7 +565,13 @@ pairs.emmGrid = function(x, reverse = FALSE, ...) {
 
 # coef method - returns contrast coefficients
 #' @rdname contrast 
-#' @return \code{coef} returns a \code{data.frame} containing the object's grid, along with columns named \code{c.1, c.2, ...} containing the contrast coefficients. If 
+#' @return \code{coef} returns a \code{data.frame} containing the "parent" object's grid, 
+#' along with columns named \code{c.1, c.2, ...} containing the contrast coefficients
+#' used to produce the linear functions embodied in the object. \code{coef()} only
+#' returns coefficients if \code{object} is the result of a call to \code{contrast()},
+#' and the parent object is the object that was handed to \code{contrast}. This
+#' is most useful for understanding interaction contrasts.
+#'
 #' @export
 #' @importFrom stats coef
 #' @method coef emmGrid
